==> mayan_edms-3.2rc1-py2.py3-none-any.whl: mayan/apps/events/migrations/0003_notification.py <==
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('actstream', '0002_remove_action_data'),
        ('events', '0002_eventsubscription'),
    ]

    operations = [
        migrations.CreateModel(
            name='Notification',
            fields=[
                (
                    'id', models.AutoField(
                        auto_created=True, primary_key=True, serialize=False,
                        verbose_name='ID'
                    )
                ),
                (
                    'read', models.BooleanField(
                        default=False, verbose_name='Read'
                    )
                ),
                (
                    'action', models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='notifications', to='actstream.Action',
                        verbose_name='Action'
                    )
                ),
                (
                    'user', models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='notifications',
                        to=settings.AUTH_USER_MODEL, verbose_name='User'
                    )
                ),
            ],
            options={
                'verbose_name': 'Notification',
                'verbose_name_plural': 'Notifications',
            },
        ),
    ]

==> mayan_edms-4.5.13-py2.py3-none-any.whl: mayan/apps/events/migrations/0003_notification.py <==
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('actstream', '0002_remove_action_data'),
        ('events', '0002_eventsubscription')
    ]

    operations = [
        migrations.CreateModel(
            name='Notification',
            fields=[
                (
                    'id', models.AutoField(
                        auto_created=True, primary_key=True, serialize=False,
                        verbose_name='ID'
                    )
                ),
                (
                    'read', models.BooleanField(
                        default=False, verbose_name='Read'
                    )
                ),
                (
                    'action', models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='notifications', to='actstream.Action',
                        verbose_name='Action'
                    )
                ),
                (
                    'user', models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='notifications',
                        to=settings.AUTH_USER_MODEL, verbose_name='User'
                    )
                )
            ],
            options={
                'verbose_name': 'Notification',
                'verbose_name_plural': 'Notifications'
            }
        )
    ]
